==> chaosmesh-model-6.3.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodIOChaosListFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface PodIOChaosListFluent<A extends PodIOChaosListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,PodIOChaos item);
  public A setToItems(Integer index,PodIOChaos item);
  public A addToItems(io.fabric8.chaosmesh.v1alpha1.PodIOChaos... items);
  public A addAllToItems(Collection<PodIOChaos> items);
  public A removeFromItems(io.fabric8.chaosmesh.v1alpha1.PodIOChaos... items);
  public A removeAllFromItems(Collection<PodIOChaos> items);
  public A removeMatchingFromItems(Predicate<PodIOChaosBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PodIOChaos> getItems();
  public List<PodIOChaos> buildItems();
  public PodIOChaos buildItem(Integer index);
  public PodIOChaos buildFirstItem();
  public PodIOChaos buildLastItem();
  public PodIOChaos buildMatchingItem(Predicate<PodIOChaosBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<PodIOChaosBuilder> predicate);
  public A withItems(List<PodIOChaos> items);
  public A withItems(io.fabric8.chaosmesh.v1alpha1.PodIOChaos... items);
  public Boolean hasItems();
  public PodIOChaosListFluent.ItemsNested<A> addNewItem();
  public PodIOChaosListFluent.ItemsNested<A> addNewItemLike(PodIOChaos item);
  public PodIOChaosListFluent.ItemsNested<A> setNewItemLike(Integer index,PodIOChaos item);
  public PodIOChaosListFluent.ItemsNested<A> editItem(Integer index);
  public PodIOChaosListFluent.ItemsNested<A> editFirstItem();
  public PodIOChaosListFluent.ItemsNested<A> editLastItem();
  public PodIOChaosListFluent.ItemsNested<A> editMatchingItem(Predicate<PodIOChaosBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,PodIOChaosFluent<PodIOChaosListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodIOChaosListFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface PodIOChaosListFluent<A extends PodIOChaosListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,PodIOChaos item);
  public A setToItems(int index,PodIOChaos item);
  public A addToItems(io.fabric8.chaosmesh.v1alpha1.PodIOChaos... items);
  public A addAllToItems(Collection<PodIOChaos> items);
  public A removeFromItems(io.fabric8.chaosmesh.v1alpha1.PodIOChaos... items);
  public A removeAllFromItems(Collection<PodIOChaos> items);
  public A removeMatchingFromItems(Predicate<PodIOChaosBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PodIOChaos> getItems();
  public List<PodIOChaos> buildItems();
  public PodIOChaos buildItem(int index);
  public PodIOChaos buildFirstItem();
  public PodIOChaos buildLastItem();
  public PodIOChaos buildMatchingItem(Predicate<PodIOChaosBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<PodIOChaosBuilder> predicate);
  public A withItems(List<PodIOChaos> items);
  public A withItems(io.fabric8.chaosmesh.v1alpha1.PodIOChaos... items);
  public Boolean hasItems();
  public PodIOChaosListFluent.ItemsNested<A> addNewItem();
  public PodIOChaosListFluent.ItemsNested<A> addNewItemLike(PodIOChaos item);
  public PodIOChaosListFluent.ItemsNested<A> setNewItemLike(int index,PodIOChaos item);
  public PodIOChaosListFluent.ItemsNested<A> editItem(int index);
  public PodIOChaosListFluent.ItemsNested<A> editFirstItem();
  public PodIOChaosListFluent.ItemsNested<A> editLastItem();
  public PodIOChaosListFluent.ItemsNested<A> editMatchingItem(Predicate<PodIOChaosBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,PodIOChaosFluent<PodIOChaosListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
